# Generated by Django 4.0.1 on 2022-02-18 09:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('config', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sidebar',
            name='display_type',
            field=models.PositiveIntegerField(choices=[(1, 'HTML'), (3, '最新文章'), (2, '最热文章'), (4, '最近评论')], default=1, verbose_name='展示类型'),
        ),
    ]
