{% extends "./base.html" %}
{% load comment_block %}
{% block title %} {{post.title}} {% endblock %}
{% block extra_head%}

{% load static %}
 <link rel="stylesheet" href="{%static 'css/bootstrap.css'%}">

</script>
<script>hljs.initHighlightingOnLoad();</script>
{% endblock %}

{% block main %}
{% if post %}
<h1> {{ post.title }}</h1>
<div>
    <span>分类:<a href="{% url 'category-list' post.category.id %}">{{ post.category.name }}</a> </span>
    <span>作者:<a href="{% url 'author' post.owner.id %}">{{ post.owner }}</a></span>
</div>
<br/>
{% autoescape off %}
<p>{{ post.content }}</p>
{% endautoescape %}
{% endif %}
{% comment_block request.path %}

{% endblock %}
