from django.shortcuts import render
from django.http import  HttpResponse
from blog.models import Post
from comment.models import Comment
from config.models import SideBar,Link
from blog.views import CommonViewMixin
from django.views.generic import  ListView

# Create your views here.
class LinkListView(CommonViewMixin,ListView):
    queryset = Link.objects.filter(status=Link.STATUS_NORMAL)
    template_name = 'config/links.html'
    context_object_name = 'link_list'


