<!doctype html>
<html>
<head>
    <title>
        评论结果页
    </title>
    <style>
        body {text-align: center;}
        .result {
            text-align: center;
            width: 40%;
            margin: auto;
        }
        .errorlist {color: red;}
        ul li {
            list-style-type: none;
        }
    </style>
</head>
<body>
<div class="result">
    {% if succeed %}
    评论成功
    <a href={{ target }}>返回</a>
    {% else %}
    <ul class = "errorlist">
        {% for field, message in form.errors.items %}
        <li>{{ message }}</li>
        {% endfor %}
    </ul>
    <a href="javascript:window.history.back();">返回</a>
    {% endif %}
</div>
</body>
</html>