# Generated by Django 4.0.1 on 2022-02-17 02:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('blog', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='category',
            name='is_nav',
            field=models.BooleanField(default=False, verbose_name='是否是导航'),
        ),
        migrations.AlterField(
            model_name='category',
            name='name',
            field=models.CharField(max_length=50, verbose_name='名称'),
        ),
    ]
