from django.contrib import admin
from .models import Link,SideBar
from typeidea.custom_site import custom_site
from typeidea.base_admin import BaseOwnerAdmin
# Register your models here.
@admin.register(Link,site=custom_site)
class Linkadmin(BaseOwnerAdmin):
    list_display = ('title', 'href', 'status', 'weight', 'created_time')
    fields = ('title', 'href', 'status', 'weight')
    def save_model(self, request, obj, form, change):
        obj.owner = request.user
        return super(Linkadmin, self).save_model(request,obj, form, change)

@admin.register(SideBar,site=custom_site)
class SideBaradmin(BaseOwnerAdmin):
    list_display = ('title', 'display_type', 'content', 'created_time')
    fields = ('title', 'display_type', 'content')
    def save_model(self, request, obj, form, change):
        obj.owner = request.user
        return super(SideBaradmin, self).save_model(request,obj, form, change)